@@ -17,11 +17,15 @@
 
 """Viewer for NFO files."""
 
-__version__ = "1.16"
+__version__ = "1.19"
+
+import gi
+gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
 
 from nfoview.paths import *
-from nfoview import i18n
 from nfoview import util
+from nfoview import i18n
 from nfoview.errors import *
 from nfoview.config import *
 conf = ConfigurationStore(read=True)
@@ -41,5 +45,6 @@ from nfoview.unittest import *
 def main(paths):
     """Initialize application."""
     global app
+    i18n.bind()
     app = Application(paths)
     raise SystemExit(app.run())
